@@ -10,7 +10,7 @@ from pkg_resources import resource_string
 from .version import __version__
 
 # read logging config from package resource
-LOGGER_CONFIG = resource_string(__name__, 'logging.yml')
+LOGGER_CONFIG = resource_string(__name__, "logging.yml")
 
 
 def _setup_logger(cfg_path):
