@@ -10,17 +10,23 @@ from me_finder.context import ExecutionContext
 from me_finder.io import ContigSequences
 from mgedb import Sequence, Sequences
 
-from .parse import (Alignments, _get_element_coord, _get_mge_hit,
-                    _is_overlapping)
-from .types import (Alignment, ElementCoordinate, ElementHit, MgeFinderResult,
-                    MgeResult, PredictionEvidence, TemplateSequence)
+from .parse import Alignments, _get_element_coord, _get_mge_hit, _is_overlapping
+from .types import (
+    Alignment,
+    ElementCoordinate,
+    ElementHit,
+    MgeFinderResult,
+    MgeResult,
+    PredictionEvidence,
+    TemplateSequence,
+)
 
 LOG = logging.getLogger(__name__)
 
 
 def _is_valid_hit(hit: ElementHit, ctx: ExecutionContext) -> bool:
     """Validate good hits."""
-    cnf_cov = ctx.cnf_get_default('getfloat', 'validation', 'coverage')
+    cnf_cov = ctx.cnf_get_default("getfloat", "validation", "coverage")
     if hit.tot_aln_cov < cnf_cov:
         return False
 
@@ -31,7 +37,7 @@ def _is_valid_hit(hit: ElementHit, ctx: ExecutionContext) -> bool:
     # if no hit is significant
     if not any(h.e_value == 0 for h in hit.hsps):
         evals = (math.log10(h.e_value) for h in hit.hsps)
-        cnf_eval = ctx.cnf_get_default('getfloat', 'validation', 'e_value')
+        cnf_eval = ctx.cnf_get_default("getfloat", "validation", "e_value")
         if max(evals) > cnf_eval:
             return False
 
@@ -84,7 +90,9 @@ def _pad_mge_coord(elem: ElementHit, padding: float) -> Tuple[int, int]:
     return round(nstart), round(end + (length / 2))
 
 
-def _detect_mges(ctx: ExecutionContext, raw_mges, contigs: ContigSequences) -> Tuple[MgeFinderResult, Sequences, Alignments]:
+def _detect_mges(
+    ctx: ExecutionContext, raw_mges, contigs: ContigSequences
+) -> Tuple[MgeFinderResult, Sequences, Alignments]:
     """Find valid mobile element from blast reult and annotate output.
 
     HSPs for each hit is combined and the total alignment is summarized. The quality of the total
@@ -93,7 +101,7 @@ def _detect_mges(ctx: ExecutionContext, raw_mges, contigs: ContigSequences) -> T
     Returns a tuple with [prediction resultr, sequence, alignments]
 
     """
-    LOG.info('detecting MGEs')
+    LOG.info("detecting MGEs")
     # get mge records
     valid_mges = (mge for mge in raw_mges if _is_valid_hit(mge, ctx))
     mge_records = ctx.mge_db.records  # read records to memeory
@@ -105,21 +113,19 @@ def _detect_mges(ctx: ExecutionContext, raw_mges, contigs: ContigSequences) -> T
     mge_indexer = 1
     for _, hits in groupby(valid_mges, key=lambda x: x.query_name):
         for hit_bin in _bin_hits(hits):
-            best_hit = max(hit_bin,
-                           key=lambda h:
-                           (h.tot_aln_cov, h.avg_seq_id, h.subject_len))
+            best_hit = max(
+                hit_bin, key=lambda h: (h.tot_aln_cov, h.avg_seq_id, h.subject_len)
+            )
             header_info = _get_mge_hit(best_hit)
-            entry = mge_records[header_info['name']]
+            entry = mge_records[header_info["name"]]
 
             start, end = _get_element_coord(best_hit)
-            mge_seq = contigs.sub_sequence(start - 1, end, 1,
-                                           best_hit.query_name)
+            mge_seq = contigs.sub_sequence(start - 1, end, 1, best_hit.query_name)
 
             # store fasta header
-            header = '|'.join([
-                header_info['name'], header_info['seq_no'],
-                header_info['accession']
-            ])
+            header = "|".join(
+                [header_info["name"], header_info["seq_no"], header_info["accession"]]
+            )
             mge_headers.append(header)
             # add header to sequence
             mge_seq = attr.evolve(mge_seq, title=header)
@@ -128,19 +134,18 @@ def _detect_mges(ctx: ExecutionContext, raw_mges, contigs: ContigSequences) -> T
             # TODO clean up
             if mge_seq in mge_sequences:
                 # store id of previously stored sequence
-                mge_id = int(mge_sequences[mge_seq].title.split('|')[1])
+                mge_id = int(mge_sequences[mge_seq].title.split("|")[1])
             else:
                 header = f'{header_info["name"]}|{mge_indexer}'
                 mge_id = mge_indexer
                 # if header in (s.title for s in mge_sequences):
                 #     pass
-                mge_sequences.append(Sequence(title=header,
-                                                  seq=mge_seq.seq))
-            template = entry.sequences[int(header_info['seq_no']) - 1]
+                mge_sequences.append(Sequence(title=header, seq=mge_seq.seq))
+            template = entry.sequences[int(header_info["seq_no"]) - 1]
 
-            template = TemplateSequence(accession=template.accession,
-                                        start=template.start,
-                                        end=template.end)
+            template = TemplateSequence(
+                accession=template.accession, start=template.start, end=template.end
+            )
             truncation_level = best_hit.truncation_level()
             # make entry
             mges.append(
@@ -156,9 +161,9 @@ def _detect_mges(ctx: ExecutionContext, raw_mges, contigs: ContigSequences) -> T
                     template=template,
                     reference=entry.references,
                     alias=entry.synonyms,
-                    seq_no=int(header_info['seq_no']),
-                    trunc_5p=truncation_level['trunc_5p'],
-                    trunc_3p=truncation_level['trunc_3p'],
+                    seq_no=int(header_info["seq_no"]),
+                    trunc_5p=truncation_level["trunc_5p"],
+                    trunc_3p=truncation_level["trunc_3p"],
                     start=start,
                     end=end,
                     strand=best_hit.hsps[0].hit_strand,
@@ -174,17 +179,22 @@ def _detect_mges(ctx: ExecutionContext, raw_mges, contigs: ContigSequences) -> T
                     template_length=best_hit.subject_len,
                     num_hsps=len(best_hit.hsps),
                     carried_motifs=[],
-                    cigar=best_hit.cigar))
+                    cigar=best_hit.cigar,
+                )
+            )
             for hsp_no, hsp in enumerate(best_hit.hsps, start=1):
                 alignments.append(
-                    Alignment(name=entry.name,
-                              mge_id=str(mge_id),
-                              hsp_no=hsp_no,
-                              subject_start=hsp.subject_start,
-                              subject_end=hsp.subject_end,
-                              query_seq=hsp.query_seq,
-                              midline=hsp.midline,
-                              subject_seq=hsp.subject_seq))
+                    Alignment(
+                        name=entry.name,
+                        mge_id=str(mge_id),
+                        hsp_no=hsp_no,
+                        subject_start=hsp.subject_start,
+                        subject_end=hsp.subject_end,
+                        query_seq=hsp.query_seq,
+                        midline=hsp.midline,
+                        subject_seq=hsp.subject_seq,
+                    )
+                )
             mge_indexer += 1
     # TODO simplify this function
     return tuple(mges), tuple(mge_sequences), tuple(alignments)
