@@ -1,6 +1,11 @@
 """Collection of cli tool wrappers."""
-from .blast import (BlastHit, BlastHsp, blastdb_exist, database_environment,
-                    iter_blast_hits)
+from .blast import (
+    BlastHit,
+    BlastHsp,
+    blastdb_exist,
+    database_environment,
+    iter_blast_hits,
+)
 from .blast import make_database as make_blast_database
 from .blast import run_blast
 from .kma import ReadDepth, get_read_depth
